/* This file contains various GUI dialogs and requester windows. */
#include <gui/window.h>
#include <gui/layoutview.h>
#include <gui/stringview.h>
#include <gui/textview.h>
#include <gui/button.h>
#include <util/message.h>

#include "requesters.h"
#include "messages.h"


/**** Delete confirmation dialog *****/

DeleteConfirmDialog::DeleteConfirmDialog( std::vector< RemoteNode >* pacNodes, Handler* pcTarget )
	: Window( Rect(0,0,100,60), "delete_dialog", "Delete files" )
{
	m_pcTarget = pcTarget;
	m_pacNodes = pacNodes;
	
	VLayoutNode* pcLayout = new VLayoutNode( "vnode" );
	String zTmp;
	if( pacNodes->size() == 1 ) {
		zTmp = "Are you sure you want to delete this file?";
	} else {
		zTmp.Format( "Are you sure you want to delete these %i files?", pacNodes->size() );
	}
	StringView* pcStringView = new StringView( Rect(), "stringview", zTmp );
	pcLayout->AddChild( pcStringView );
	
	HLayoutNode* pcButtonsNode = new HLayoutNode( "hnode" );
	Button* pcYes = new Button( Rect(), "yesbutton", "Yes", new Message( M_DELETE_CONFIRMED ) );
	Button* pcNo = new Button( Rect(), "nobutton", "No", new Message( M_QUIT ) );
	pcYes->SetTarget( this );
	pcNo->SetTarget( this );
	pcButtonsNode->AddChild( pcYes );
	pcButtonsNode->AddChild( pcNo );
	pcLayout->AddChild( pcButtonsNode );
	
	LayoutView* pcView = new LayoutView( GetFrame(), "layoutview", pcLayout );
	AddChild( pcView );
}

DeleteConfirmDialog::~DeleteConfirmDialog()
{
	if( m_pacNodes ) delete( m_pacNodes );
}

void DeleteConfirmDialog::HandleMessage( Message* pcMessage )
{
	switch( pcMessage->GetCode() )
	{
		case M_DELETE_CONFIRMED:
		{
			pcMessage->AddPointer( "files", m_pacNodes );
			Messenger cMessenger( m_pcTarget );
			cMessenger.SendMessage( pcMessage );
			m_pacNodes = NULL;	/* We don't want to delete it */
			Quit();
			break;
		}
		default:
			Window::HandleMessage( pcMessage );
	}
}

/**** Rename dialog ****/

RenameRequester::RenameRequester( const String& zOldPath, Handler* pcTarget )
	: Window( Rect(0,0,100,60), "rename_dialog", "Rename file" )
{
	m_pcTarget = pcTarget;
	m_zOldPath = zOldPath;
	
	VLayoutNode* pcLayout = new VLayoutNode( "vnode" );
	StringView* pcStringView = new StringView( Rect(), "stringview", "Enter a new name for the file:" );
	pcLayout->AddChild( pcStringView );
	
	m_pcTextView = new TextView( Rect(), "rename_input", zOldPath.c_str() );
	m_pcTextView->SetMultiLine( false );
	m_pcTextView->SelectAll( false );
	pcLayout->AddChild( m_pcTextView );
	
	HLayoutNode* pcButtonsNode = new HLayoutNode( "hnode" );
	Button* pcOK = new Button( Rect(), "okbutton", "Rename", new Message( M_RENAME_CONFIRMED ) );
	Button* pcCancel = new Button( Rect(), "cancelbutton", "Cancel", new Message( M_QUIT ) );
	pcOK->SetTarget( this );
	pcCancel->SetTarget( this );
	pcButtonsNode->AddChild( pcOK );
	pcButtonsNode->AddChild( pcCancel );
	pcLayout->AddChild( pcButtonsNode );
	
	LayoutView* pcView = new LayoutView( GetFrame(), "layoutview", pcLayout );
	AddChild( pcView );
}

RenameRequester::~RenameRequester()
{
}

void RenameRequester::HandleMessage( Message* pcMessage )
{
	switch( pcMessage->GetCode() )
	{
		case M_RENAME_CONFIRMED:
		{
			pcMessage->AddString( "old_path", m_zOldPath );
			/* TODO: only use last part of path */
			pcMessage->AddString( "new_path", m_pcTextView->GetValue().AsString() );
			Messenger cMessenger( m_pcTarget );
			cMessenger.SendMessage( pcMessage );
			Quit();
			break;
		}
		default:
			Window::HandleMessage( pcMessage );
	}
}


/**** MkDir dialog ****/

MkDirRequester::MkDirRequester( const String& zBasePath, Handler* pcTarget )
	: Window( Rect(0,0,100,60), "mkdir_dialog", "Create new directory" )
{
	m_pcTarget = pcTarget;
	m_zBasePath = zBasePath;
	
	VLayoutNode* pcLayout = new VLayoutNode( "vnode" );
	StringView* pcStringView = new StringView( Rect(), "stringview", "Enter a name for the new directory:" );
	pcLayout->AddChild( pcStringView );
	
	m_pcTextView = new TextView( Rect(), "mkdir_input", "New directory" );
	m_pcTextView->SetMultiLine( false );
	m_pcTextView->SelectAll( false );
	pcLayout->AddChild( m_pcTextView );
	
	HLayoutNode* pcButtonsNode = new HLayoutNode( "hnode" );
	Button* pcOK = new Button( Rect(), "okbutton", "Create", new Message( M_MKDIR_CONFIRMED ) );
	Button* pcCancel = new Button( Rect(), "cancelbutton", "Cancel", new Message( M_QUIT ) );
	pcOK->SetTarget( this );
	pcCancel->SetTarget( this );
	pcButtonsNode->AddChild( pcOK );
	pcButtonsNode->AddChild( pcCancel );
	pcLayout->AddChild( pcButtonsNode );
	
	LayoutView* pcView = new LayoutView( GetFrame(), "layoutview", pcLayout );
	AddChild( pcView );
}

MkDirRequester::~MkDirRequester()
{
}

void MkDirRequester::HandleMessage( Message* pcMessage )
{
	switch( pcMessage->GetCode() )
	{
		case M_MKDIR_CONFIRMED:
		{
			String zTmp = m_zBasePath;
			zTmp += "/";
			zTmp += m_pcTextView->GetValue().AsString();
			pcMessage->AddString( "remotepath", zTmp );
			Messenger cMessenger( m_pcTarget );
			cMessenger.SendMessage( pcMessage );
			Quit();
			break;
		}
		default:
			Window::HandleMessage( pcMessage );
	}
}


